@@ -152,8 +152,11 @@ process_line (char     *line,
 					fdata->name = _g_path_get_dir_name (fdata->full_path);
 					fdata->dir = TRUE;
 				}
-				else
+				else {
 					fdata->name = g_strdup (_g_path_get_basename (fdata->full_path));
+					if (fields[5][0] == 'l')
+						fdata->link = g_strdup (_g_path_get_basename (fdata->full_path));
+				}
 
 				fr_archive_add_file (FR_ARCHIVE (comm), fdata);
 				rar_comm->fdata = NULL;
@@ -422,6 +425,8 @@ fr_command_rar_delete (FrCommand  *comm,
 	fr_process_begin_command (comm->process, "rar");
 	fr_process_add_arg (comm->process, "d");
 
+	add_password_arg (comm, FR_ARCHIVE (comm)->password, FALSE);
+
 	fr_process_add_arg (comm->process, "--");
 	fr_process_add_arg (comm->process, comm->filename);
 
@@ -678,6 +683,7 @@ fr_command_rar_init (FrCommandRar *self)
 	base->propExtractCanAvoidOverwrite = TRUE;
 	base->propExtractCanSkipOlder      = TRUE;
 	base->propExtractCanJunkPaths      = TRUE;
+	base->propCanDeleteAllFiles        = FALSE;
 	base->propPassword                 = TRUE;
 	base->propTest                     = TRUE;
 	base->propListFromFile             = TRUE;
